@@ -13,7 +13,7 @@ test_that("dmap() works with sliced data frames", {
 
 test_that("dmap() works with no columns to map", {
   res <- mtcars["cyl"] %>% slice_rows("cyl") %>% dmap(mean)
-  expect_equal(res, mtcars["cyl"])
+  expect_equal(res, dplyr::group_by(mtcars["cyl"], cyl))
 })
 
 test_that("dmap() recycles only vectors of length 1", {
@@ -28,7 +28,7 @@ test_that("conditional sliced mapping recycles within groups", {
   res_at <- dmap_at(df, c("disp", "drat"), mean)
   res_if <- dmap_if(df, ~ .x[[1]] == 160, mean)
 
-  expected <- purrr::map2(expected_df$disp, attr(df, "group_sizes"), rep) %>% purrr::flatten_dbl()
+  expected <- purrr::map2(expected_df$disp, group_sizes(df), rep) %>% purrr::flatten_dbl()
   expect_equal(res_at$disp, expected)
   expect_equal(res_if$disp, expected)
 })
